@@ -1,6 +1,7 @@
 import os
 
 from python_grains.profiles.profiles import Profile
+from python_grains.profiles.stitches import Stitch, StitchPool
 from python_grains.profiles.profile_properties import (PROFILE_VALUE_CREATED_POSTFIX,
                                                        PROFILE_VALUE_UPDATED_POSTFIX,
                                                        PROFILE_VALUE_EXPIRE_AT_POSTFIX,
@@ -105,6 +106,25 @@ def attach_profile_lua_scripts(redis_client,
 
     return redis_client
 
+def attach_stitch_lua_scripts(redis_client):
+
+    if not hasattr(redis_client, 'get_multiple_stitches'):
+
+        redis_client.get_multiple_stitches = redis_client.register_script(
+            LuaScripts.get_multiple_stitches())
+
+    if not hasattr(redis_client, 'get_stitched_user_profile'):
+
+        redis_client.get_stitched_user_profile = redis_client.register_script(
+            LuaScripts.get_stitched_user_profile(
+                value_postfix=PROFILE_VALUE_POSTFIX,
+                updated_postfix=PROFILE_VALUE_UPDATED_POSTFIX,
+                created_postfix=PROFILE_VALUE_CREATED_POSTFIX,
+                expire_postfix=PROFILE_VALUE_EXPIRE_AT_POSTFIX
+            ))
+
+    return redis_client
+
 def getProfileClass(
         domain,
         fast_clean_threshold,
@@ -139,4 +159,41 @@ def getProfileClass(
     cls.user_data_ttl_margin = user_data_ttl_margin
     cls.clean_queue_ttl = clean_queue_ttl
 
+    return cls
+
+def getStitchClass(
+        domain,
+        redis_client,
+        django_stitch_model,
+        django_connection_tuple,
+        user_ttl=None,
+        user_data_ttl_margin=None):
+
+    cls = Stitch
+    cls.domain = domain
+    cls.redis_client = attach_stitch_lua_scripts(redis_client=redis_client)
+    cls.django_stitch_model = django_stitch_model
+    cls.django_connection_tuple = django_connection_tuple
+    cls.user_ttl = user_ttl
+    cls.user_data_ttl_margin = user_data_ttl_margin
+
+    return cls
+
+
+def getStitchPoolClass(
+        domain,
+        redis_client,
+        django_stitch_pool_model,
+        django_connection_tuple,
+        user_ttl=None,
+        user_data_ttl_margin=None):
+
+    cls = StitchPool
+    cls.domain = domain
+    cls.redis_client = attach_stitch_lua_scripts(redis_client=redis_client)
+    cls.django_stitch_model = django_stitch_pool_model
+    cls.django_connection_tuple = django_connection_tuple
+    cls.user_ttl = user_ttl
+    cls.user_data_ttl_margin = user_data_ttl_margin
+
     return cls
\ No newline at end of file
