@@ -395,7 +395,7 @@ class Profile(object):
         data_dict = {k.decode(): {pk.decode(): pr for pk, pr in dict(zip(v[::2], v[1::2])).items()} if v else None
                      for k, v in dict(zip(data[::2], data[1::2])).items()}
         # incomplete users are users that have profile keys in their profile pool, whose profile is not present
-        incomplete_users = {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items() if not v or any(not bool(x) for x in v.values())}
+        incomplete_users = {cls._user_id_from_profile_pool_key(k): v or {} for k, v in data_dict.items() if not v or any(not bool(x) for x in v.values())}
         complete_users = {u:p for u,p in {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items()}.items() if not u in incomplete_users}
 
         complete_profiles = [p for p in [cls.from_redis_data(data=d,
@@ -410,7 +410,7 @@ class Profile(object):
             complemented_profiles = []
             for user_id, profiles_for_user in incomplete_users.items():
                 from_db_for_user = from_db.get(user_id, [])
-                if profiles_for_user is None or len(profiles_for_user) == 0:
+                if len(profiles_for_user) == 0:
                     if len(from_db_for_user) == 0:
                         missing_users.append(user_id)
                     else:
